==> DynamicGP_1.0-1.tar.gz: DynamicGP/R/knnsvdGP.r <==
knnsvdGP <- function(design, resp, X0=design, nn=20, nsvd = nn, frac = .9,
                     gstart = 0.0001, nstarts = 5,centralize=FALSE, maxit=100, verb=0,
                     nthread = 4, clutype="PSOCK")
{
    if(.Platform$r_arch=="i386")
    {
        cat("the current version does not support 32bit architecture, exit\n")
        return(NULL)
    }
    if(!is.matrix(design)) stop("design must be a matrix")
    if(!is.matrix(resp)) stop("resp must be a matrix")
    N <- nrow(design)
    m <- ncol(design)
    if(ncol(resp) != N)
        stop("number of design points and responses are not consistent")
    tlen <- nrow(resp)
    if(!is.matrix(X0) && length(X0) != m)
        stop("illegal form of prediction set")
    if(!is.matrix(X0)) X0 <- matrix(X0,ncol=m)
    if(ncol(X0) != m) stop("dimensions of design and prediction set are not consistent")
    M <- nrow(X0)
    if(nthread > 1)
    {
        if(nstarts > 1)
            ret <- lasvdgpmsParal(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                  nstarts=nstarts,centralize=centralize,maxit=maxit,
                                  verb=verb,nthread=nthread,clutype=clutype)
        else
            ret <- lasvdgpParal(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                centralize=centralize,maxit=maxit,verb=verb,
                                nthread=nthread,clutype=clutype)
    }
    else
    {
        if(nstarts > 1)
            ret <- lasvdgpms(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                             nstarts=nstarts,centralize=centralize,maxit=maxit,
                             verb=verb)
        else
            ret <- lasvdgpWorker(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                 centralize=centralize,maxit=maxit,verb=verb)
    }
    return(ret)
}

==> DynamicGP_1.0-2.tar.gz: DynamicGP/R/knnsvdGP.r <==
knnsvdGP <- function(design, resp, X0=design, nn=20, nsvd = nn, frac = .9,
                     gstart = 0.0001, nstarts = 5,centralize=FALSE, maxit=100, verb=0,
                     nthread = 4, clutype="PSOCK")
{
    if(.Machine$sizeof.pointer != 8)
    {
        cat("the current version only supports 64-bit version of R\n")
        return(NULL)
    }
    if(!is.matrix(design)) stop("design must be a matrix")
    if(!is.matrix(resp)) stop("resp must be a matrix")
    N <- nrow(design)
    m <- ncol(design)
    if(ncol(resp) != N)
        stop("number of design points and responses are not consistent")
    tlen <- nrow(resp)
    if(!is.matrix(X0) && length(X0) != m)
        stop("illegal form of prediction set")
    if(!is.matrix(X0)) X0 <- matrix(X0,ncol=m)
    if(ncol(X0) != m) stop("dimensions of design and prediction set are not consistent")
    M <- nrow(X0)
    if(nthread > 1)
    {
        if(nstarts > 1)
            ret <- lasvdgpmsParal(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                  nstarts=nstarts,centralize=centralize,maxit=maxit,
                                  verb=verb,nthread=nthread,clutype=clutype)
        else
            ret <- lasvdgpParal(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                centralize=centralize,maxit=maxit,verb=verb,
                                nthread=nthread,clutype=clutype)
    }
    else
    {
        if(nstarts > 1)
            ret <- lasvdgpms(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                             nstarts=nstarts,centralize=centralize,maxit=maxit,
                             verb=verb)
        else
            ret <- lasvdgpWorker(X0,design,resp,nn,nn,frac=frac,gstart=gstart,
                                 centralize=centralize,maxit=maxit,verb=verb)
    }
    return(ret)
}
